Package: plsRglm
Version: 1.7.1
Date: 2026-06-04
Depends: R (>= 2.10)
Imports: mvtnorm, boot, bipartite, car, MASS, Rcpp
LinkingTo: Rcpp, RcppArmadillo
Enhances: pls
Suggests: chemometrics, knitr, plsdof, plsdepot, plspm, fastglm,
        plsRcox, rmarkdown, testthat (>= 3.0.0), xtable
Title: Partial Least Squares Regression for Generalized Linear Models
Authors@R: c(
	person(given = "Frederic", family= "Bertrand", role = c("cre", "aut"), email = "frederic.bertrand@lecnam.net", comment = c(ORCID = "0000-0002-0837-8281")),
	person(given = "Myriam", family= "Maumy-Bertrand", role = c("aut"), email = "myriam.maumy@ehesp.fr", comment = c(ORCID = "0000-0002-4615-1512")))
Author: Frederic Bertrand [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-0837-8281>),
  Myriam Maumy-Bertrand [aut] (ORCID:
    <https://orcid.org/0000-0002-4615-1512>)
Maintainer: Frederic Bertrand <frederic.bertrand@lecnam.net>
Description: Provides (weighted) Partial least squares Regression for generalized linear models and repeated k-fold cross-validation of such models using various criteria <doi:10.48550/arXiv.1810.01005>. It allows for missing data in the explanatory variables. Bootstrap confidence intervals constructions are also available.
License: GPL-3
Encoding: UTF-8
URL: https://fbertran.github.io/plsRglm/,
        https://github.com/fbertran/plsRglm
BugReports: https://github.com/fbertran/plsRglm/issues
VignetteBuilder: knitr
Classification/MSC: 62J12, 62J99
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: yes
Packaged: 2026-06-10 20:34:18 UTC; bertran7
Repository: CRAN
Date/Publication: 2026-06-17 10:40:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-06-17 14:51:20 UTC; unix
Archs: plsRglm.so.dSYM
