# imports functions
useDynLib(plsRglm, .registration=TRUE)
importFrom(Rcpp, evalCpp)
importFrom("graphics", "abline", "arrows", "axis", "barplot",
           "boxplot", "legend", "par", "plot", "points", "strwidth",
           "text")
importFrom("stats", "AIC", "Gamma", "binomial", "coef", "contrasts",
           "family", "gaussian", "glm", "inverse.gaussian",
           "is.empty.model", "lm", "make.link", "model.frame",
           "model.matrix", "model.offset", "model.response",
           "model.weights", "na.exclude", "na.pass", "pnorm",
           "poisson", "predict", "rbinom", "residuals",
           "residuals.glm", "weighted.mean")

importFrom(MASS,polr)
importFrom(mvtnorm,rmvnorm)
importFrom(bipartite,visweb)
importFrom(car,dataEllipse)
import(boot)

# functions
export(aic.dof                   )
export(AICpls                    ) 
export(bic.dof                   )
export(bootpls                   )
export(bootplsglm                )
export(boxplots.bootpls          )
export(classbiplot               )
export(confints.bootpls          )
export(confints2signifind       )
export(coef.plsRmodel            ) 
export(coef.plsRglmmodel         ) 
export(coefs.plsR                ) 
export(coefs.plsRglm             ) 
export(coefs.plsR.raw            ) 
export(coefs.plsRglm.raw         ) 
export(coefs.plsRglmnp           ) 
export(coefs.plsRnp              ) 
export(cv.plsR                   ) 
export(cv.plsRmulti              )
export(cv.plsRglm                ) 
export(cv.plsRglmmodel.default   ) 
export(cv.plsRglmmodel.formula   ) 
export(cv.plsRmultiModel         )
export(cv.plsRmultiModel.default )
export(cv.plsRmultiModel.formula )
export(cv.plsRmodel.default      ) 
export(cv.plsRmodel.formula      ) 
export(cvtable                   ) 
export(cvtable.plsR              ) 
export(cvtable.plsRglm           ) 
export(dicho                     ) 
export(gmdl.dof                  )
export(kfolds2Chisq              ) 
export(kfolds2Chisqind           ) 
export(kfolds2coeff              ) 
export(kfolds2CVinfos_glm        ) 
export(kfolds2CVinfos_lm         ) 
export(kfolds2Mclassed           ) 
export(kfolds2Mclassedind        ) 
export(kfolds2Press              ) 
export(kfolds2Pressind           ) 
export(infcrit.dof               )
export(loglikpls                 ) 
export(permcoefs.plsR            ) 
export(permcoefs.plsRglm         ) 
export(permcoefs.plsR.raw        ) 
export(permcoefs.plsRglm.raw     ) 
export(permcoefs.plsRglmnp       ) 
export(permcoefs.plsRnp          ) 
export(plot.table.summary.cv.plsRglmmodel) 
export(plot.table.summary.cv.plsRmodel   ) 
export(plots.confints.bootpls    )
export(PLS_glm                   ) 
export(PLS_glm_formula           ) 
export(PLS_glm_kfoldcv           ) 
export(PLS_glm_kfoldcv_formula   ) 
export(PLS_glm_wvc               ) 
export(PLS_lm                    ) 
export(PLS_lm_formula            ) 
export(PLS_lm_kfoldcv            ) 
export(PLS_lm_kfoldcv_formula    ) 
export(PLS_lm_wvc                ) 
export(plsR                      ) 
export(plsR.dof                  )
export(plsRmulti                 )
export(plsRmultiModel            )
export(plsRglm                   ) 
export(plsRglmmodel.default      ) 
export(plsRglmmodel.formula      ) 
export(plsRmultiModel.default    )
export(plsRmultiModel.formula    )
export(plsRmodel.default         ) 
export(plsRmodel.formula         ) 
export(predict.plsRglmmodel      ) 
export(predict.plsRmultiModel    )
export(predict.plsRmodel         ) 
export(print.plsRglmmodel        ) 
export(print.plsRmodel           ) 
export(print.cv.plsRglmmodel     ) 
export(print.cv.plsRmodel        ) 
export(print.summary.plsRglmmodel) 
export(print.summary.plsRmodel   ) 
export(signpred                  ) 
export(simul_data_complete       ) 
export(simul_data_YX             ) 
export(simul_data_UniYX          ) 
export(simul_data_UniYX_binom    ) 
export(summary.cv.plsRglmmodel   ) 
export(summary.cv.plsRmultiModel )
export(summary.cv.plsRmodel      )
export(summary.plsRglmmodel      ) 
export(summary.plsRmodel         )
export(tilt.bootpls              )
export(tilt.bootplsglm           )
export(weighted_significance     )
 


## S3 methods for generics in base
S3method("plsRmodel", "default")
S3method("plsRmodel", "formula")
S3method("plsRmultiModel", "default")
S3method("plsRmultiModel", "formula")
S3method("plsRglmmodel", "default")
S3method("plsRglmmodel", "formula")
S3method("cv.plsRmodel", "default")
S3method("cv.plsRmodel", "formula")
S3method("cv.plsRmultiModel", "default")
S3method("cv.plsRmultiModel", "formula")
S3method("cv.plsRglmmodel", "default")
S3method("cv.plsRglmmodel", "formula")
S3method("coef", "plsRmodel")
S3method("coef", "plsRglmmodel")
S3method("plot", "table.summary.cv.plsRglmmodel")
S3method("plot", "table.summary.cv.plsRmodel")
S3method("print", "coef.plsRmodel")
S3method("print", "coef.plsRglmmodel")
S3method("print", "cv.plsRmodel")
S3method("print", "cv.plsRglmmodel")
S3method("summary", "cv.plsRmodel")
S3method("summary", "cv.plsRmultiModel")
S3method("summary", "cv.plsRglmmodel")
S3method("predict", "plsRmodel")
S3method("predict", "plsRmultiModel")
S3method("predict", "plsRglmmodel")
S3method("print", "plsRmodel")
S3method("print", "plsRmultiModel")
S3method("print", "plsRglmmodel")
S3method("summary", "plsRmodel")
S3method("summary", "plsRglmmodel")
S3method("print", "summary.plsRmodel")
S3method("print", "summary.plsRglmmodel")
